#! /bin/sh
####################################################
# Description
# Create SSL certificates and JKS store files for
# a client and Webhook probe based on the
# FQDN of the two hosts
####################################################
# Read command line arguments
####################################################
if [ $# -ne 2 ]
then
echo
echo "Usage : `basename $0` [Webhook FQDN] [Webhook EXT]"
echo
echo "Where [Webhook EXT] is like"
echo " SAN=dns:test.company.com,ip:192.168.20.20"
exit
fi
####################################################
# Server and Client FQDN
####################################################
WEBHOOKFQDN=$1
WEBHOOK_EXT=$2
export WEBHOOKFQDN WEBHOOK_EXT
####################################################
# Check and set java
####################################################
export JAVA_HOME
JAVA_HOME=$NCHOME/platform/linux2x86/jre64_1.8.0/jre
if [ ! -f ${JAVA_HOME}/bin/keytool ]
then
echo "Did not find keytool in : ${JAVA_HOME}/bin"
exit
fi
####################################################
# SSL parameters
####################################################
# Set a common passphrase for everything for now
####################################################
PASSPHRASE="netcool"
MYOU="Netcool"
MYO="IBM"
MYCITY="New York"
MYSTATE="New York"
MYCC="US"
####################################################
export MYOU MYO MYCITY MYSTATE MYCC PASSPHRASE
####################################################
# Set path to common java
####################################################
PATH=${JAVA_HOME}/bin:$PATH
####################################################
# Clean up old files
####################################################
echo "*** Cleaning up old files"
rm -rf CACERTS
mkdir CACERTS
cd CACERTS
####################################################
# Echo out parameters
####################################################
echo "*** Using the following parameters"
echo "Server FQDN   : $WEBHOOKFQDN"
echo "Probe FQDN    : $WEBHOOK_EXT"
echo "Passphrase is : $PASSPHRASE"
echo "Type passphrase/password ${PASSPHRASE} when prompted"
echo "Type yes to trust certificates"
echo "Hit return to continue>"
read n
####################################################
# Create ROOT CA
####################################################
echo "*** Create CA Certificate"
RANDFILE=rand
export RANDFILE
openssl req -new -keyout cakey.pem -out careq.pem <<EOF
${MYCC}
${MYSTATE}
${MYCITY}
${MYO}
${MYOU}
${WEBHOOKFQDN}
root@${WEBHOOKFQDN}
${PASSPHRASE}
${MYO}
EOF


openssl x509 -signkey cakey.pem -req -days 3650 -in careq.pem -out caroot.cert -extensions v3_ca

ls -l

echo "*** Creating TrustStore.jks"
keytool -keystore TrustStore.jks -alias WEBHOOKROOTCA -import -file caroot.cert -storepass ${PASSPHRASE}

echo "*** Creating KeyStore.jks"
keytool -genkeypair -keystore KeyStore.jks \
-alias webhook \
-ext ${WEBHOOK_EXT} \
-validity 3650 -keyalg RSA \
-storepass ${PASSPHRASE} \
<<EOF
${WEBHOOKFQDN}
${MYOU}
${MYO}
${MYCITY}
${MYSTATE}
${MYCC}
yes
${PASSPHRASE}
EOF



keytool -keystore KeyStore.jks -alias webhook \
-certreq -file webhook.unsigned.cert -storepass ${PASSPHRASE}

# Need to preserve extensions for SANs
echo "[req]
distinguished_name = req_distinguished_name
req_extensions = v3_req
prompt = no
[req_distinguished_name]
C = ${MYCC}
ST = ${MYSTATE}
L = ${MYCITY}
O = ${MYO}
OU = ${MYOU}
CN = ${WEBHOOKFQDN}
[v3_req]
keyUsage = keyEncipherment, dataEncipherment
extendedKeyUsage = serverAuth
subjectAltName = @alt_names
[alt_names]" > ./certificate.conf

# Add SANs
# DNS.1 = webhook_host.company.com
# DNS.2 = webhook_host
# DNS.3 = localhost
# ...
# IP.1 = 192.168.20.20
# IP.2 = 127.0.0.1
# ...
echo "$WEBHOOK_EXT" | awk -F= '{print $2}' | awk -F\, '{for(i=1;i<=NF;i++)print $i}' | grep -i dns | awk -F: '{if($1=="dns"||$1=="DNS")printf "DNS.%d = %s\n", NR,$2}' >> ./certificate.conf
echo "$WEBHOOK_EXT" | awk -F= '{print $2}' | awk -F\, '{for(i=1;i<=NF;i++)print $i}' | grep -i ip | awk -F: '{if($1=="ip"||$1=="IP")printf "IP.%d = %s\n", NR,$2}' >> ./certificate.conf
echo "# EOF" >> ./certificate.conf

openssl x509 \
-req -CA caroot.cert -CAkey cakey.pem -in webhook.unsigned.cert \
-out webhook.signed.cert -days 3650 -CAcreateserial  \
-extfile ./certificate.conf -extensions v3_req


keytool -keystore KeyStore.jks -alias WEBHOOKROOTCA -import -file caroot.cert -storepass ${PASSPHRASE}

keytool -keystore KeyStore.jks -alias webhook \
-import -file webhook.signed.cert -storepass ${PASSPHRASE}

keytool -export -keystore KeyStore.jks -alias webhook -file webhook.cert -storepass ${PASSPHRASE}
openssl x509 -inform DER -outform PEM -in webhook.cert -out webhook.pem

echo "*** List results"
echo "WEBHOOKROOTCA:"
keytool -printcert -v -file caroot.cert
echo "Webhook:"
keytool -printcert -file webhook.pem
echo "KeyStore.jks:"
keytool -list -keystore KeyStore.jks -storepass ${PASSPHRASE}
echo "TrustStore.jks:"
keytool -list -keystore TrustStore.jks -storepass ${PASSPHRASE}

echo "*** Created files"
ls -l

# EOF
