#! /bin/sh
####################################################
# Description
# Create SSL certificates and JKS store files
####################################################
# Read command line arguments
####################################################
if [ $# -ne 2 ]
then
echo
echo "Usage : `basename $0` [Webhook FQDN] [Webhook EXT]"
echo
echo "Where [Webhook EXT] is like"
echo " SAN=dns:test.company.com,ip:192.168.20.20"
exit
fi
####################################################
# Server and Client FQDN
####################################################
WEBHOOKFQDN=$1
WEBHOOK_EXT=$2
export WEBHOOKFQDN WEBHOOK_EXT
####################################################
# Check and set java
####################################################
export JAVA_HOME
JAVA_HOME=$NCHOME/platform/linux2x86/jre64_1.8.0/jre
if [ ! -f ${JAVA_HOME}/bin/keytool ]
then
echo "Did not find keytool in : ${JAVA_HOME}/bin"
exit
fi
####################################################
# SSL parameters
####################################################
# Set a common passphrase for everything for now
####################################################
PASSPHRASE="netcool"
MYOU="Netcool"
MYO="IBM"
MYCITY="New York"
MYSTATE="New York"
MYCC="US"
####################################################
export MYOU MYO MYCITY MYSTATE MYCC PASSPHRASE
####################################################
# Set path to common java
####################################################
PATH=${JAVA_HOME}/bin:$PATH
####################################################
# Clean up old files
####################################################
echo "*** Cleaning up old files"
rm -rf SSCERTS
mkdir SSCERTS
cd SSCERTS
####################################################
# Echo out parameters
####################################################
echo "*** Using the following parameters"
echo "Server FQDN   : $WEBHOOKFQDN"
echo "Probe FQDN    : $WEBHOOK_EXT"
echo "Passphrase is : $PASSPHRASE"
echo "Hit return to continue>"
read n
echo "*** Creating KeyStore.jks"
keytool -genkey -keystore KeyStore.jks \
-alias webhook \
-validity 3650 -genkey -keyalg RSA \
 -ext "${WEBHOOK_EXT}" \
 -storepass ${PASSPHRASE} \
<<EOF
${WEBHOOKFQDN}
${MYOU}
${MYO}
${MYCITY}
${MYSTATE}
${MYCC}
yes
${PASSPHRASE}
EOF

keytool -export -keystore KeyStore.jks -alias webhook -file webhook.cert -storepass ${PASSPHRASE}
openssl x509 -inform DER -outform PEM -in webhook.cert -out webhook.pem


echo "KeyStore.jks:"
keytool -list -keystore KeyStore.jks -storepass ${PASSPHRASE}
echo "Self-Signed certificate:"
keytool -printcert -file webhook.pem
echo "*** Created files"
ls -l

# EOF
